@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -25,7 +25,6 @@ import os
 import pygtk # for testing GTK version number
 pygtk.require ('2.0')
 import gtk
-import gtk.glade
 import gobject
 import subprocess
 import locale
@@ -35,14 +34,17 @@ import shutil
 import pickle
 import cairo
 
-print "DeVeDe 3.12"
-if sys.platform!="win32":
-	print "Locale: "+str(os.environ["LANG"])
+print "DeVeDe 3.16.8"
+if (sys.platform!="win32") and (sys.platform!="win64"):
+	try:
+		print "Locale: "+str(os.environ["LANG"])
+	except:
+		print "Locale not defined"
 
 # append the directories where we install the devede's own modules
 tipo=-1
 try:
-	fichero=open("/usr/share/devede/devede.glade","r")
+	fichero=open("/usr/share/devede/wmain.ui","r")
 	fichero.close()
 	tipo=0
 	found=True
@@ -51,7 +53,7 @@ except:
 
 if found==False:
 	try:
-		fichero=open("/usr/local/share/devede/devede.glade","r")
+		fichero=open("/usr/local/share/devede/wmain.ui","r")
 		fichero.close()
 		tipo=1
 		found=True
@@ -60,7 +62,7 @@ if found==False:
 
 if found==False:
 	try:
-		fichero=open("./devede.glade","r")
+		fichero=open("./interface/wmain.ui","r")
 		fichero.close()
 		tipo=2
 		found=True
@@ -73,11 +75,11 @@ if tipo==0:
 	#you need translations from non python code (glibc,libglade etc.)
 	#there are other access points to this function
 	#gtk.glade.bindtextdomain("devede","/usr/share/locale")
-	#arbol=gtk.glade.XML("/usr/share/devede/devede.glade",domain="devede")
+	#arbol=gtk.Builder("/usr/share/devede/devede.glade",domain="devede")
 	# append the directories where we install the devede's own modules
 
 	share_locale="/usr/share/locale"
-	glade="/usr/share/devede/devede.glade"
+	glade="/usr/share/devede"
 	sys.path.append("/usr/lib/devede")
 	font_path="/usr/share/devede"
 	pic_path="/usr/share/devede"
@@ -92,11 +94,11 @@ elif tipo==1:
 	#you need translations from non python code (glibc,libglade etc.)
 	#there are other access points to this function
 	#gtk.glade.bindtextdomain("devede","/usr/share/locale")
-	#arbol=gtk.glade.XML("/usr/local/share/devede/devede.glade",domain="devede")
+	#arbol=gtk.Builder("/usr/local/share/devede/devede.glade",domain="devede")
 
 	share_locale="/usr/share/locale" # Are you sure?
 	# if the files aren't at /usr, try with /usr/local
-	glade="/usr/local/share/devede/devede.glade"
+	glade="/usr/local/share/devede"
 	sys.path.append("/usr/local/lib/devede")
 	font_path="/usr/local/share/devede"
 	pic_path="/usr/local/share/devede"
@@ -111,11 +113,11 @@ elif tipo==2:
 	#you need translations from non python code (glibc,libglade etc.)
 	#there are other access points to this function
 	#gtk.glade.bindtextdomain("devede","/usr/share/locale")
-	#arbol=gtk.glade.XML("./devede.glade",domain="devede")
+	#arbol=gtk.Builder("./devede.glade",domain="devede")
 	
 	# if the files aren't at /usr/local, try with ./
 	share_locale="./po/"
-	glade="./devede.glade"
+	glade="./interface"
 	sys.path.append(os.getcwd())#("./")
 	font_path=os.getcwd()#"./"
 	pic_path=os.path.join(font_path, "pixmaps") #pic_path=font_path
@@ -139,8 +141,11 @@ gettext.install("devede",localedir=share_locale) # None is sys default locale
 #   Note also before python 2.3 you need the following if
 #   you need translations from non python code (glibc,libglade etc.)
 #   there are other access points to this function
-gtk.glade.bindtextdomain("devede",share_locale)
-arbol=gtk.glade.XML(glade,domain="devede")
+#gtk.glade.bindtextdomain("devede",share_locale)
+
+arbol=gtk.Builder()
+arbol.set_translation_domain("devede")
+
 #   To actually call the gettext translation functions
 #   just replace your strings "string" with gettext("string")
 #   The following shortcut are usually used:
@@ -210,6 +215,11 @@ global_vars["erase_files"]=True
 global_vars["action_todo"]=2
 global_vars["filmpath"]=""
 global_vars["help_path"]=help_path
+global_vars["finalfolder"]=""
+global_vars["sub_codepage"]="ISO-8859-1"
+global_vars["sub_language"]="EN (ENGLISH)"
+global_vars["with_menu"]=True
+#global_vars[""]=""
 
 if font_path[-1]!=os.sep:
 	font_path+=os.sep
@@ -223,7 +233,7 @@ print "Salgo de fonts"
 devede_other.load_config(global_vars) # load configuration
 
 errors="" # check for installed programs
-if sys.platform=='win32':
+if (sys.platform=="win32") or (sys.platform=="win64"):
 	try:
 		devede_other.check_program(["mplayer.exe", "-v"])
 	except:
@@ -240,6 +250,10 @@ if sys.platform=='win32':
 		devede_other.check_program(["vcdimager.exe", "--help"])
 	except:
 		errors+="vcdimager\n"
+	try:
+		devede_other.check_program(["iconv.exe", "--help"])
+	except:
+		errors+="iconv\n"
 	
 	try:
 		devede_other.check_program(["mkisofs.exe"])
@@ -270,6 +284,8 @@ else:
 		errors+="dvdauthor\n"
 	if 127==devede_other.check_program("vcdimager --help"):
 		errors+="vcdimager\n"
+	if 127==devede_other.check_program("iconv --help"):
+		errors+="iconv\n"
 	if 127==devede_other.check_program("mkisofs -help"):
 		if 127==devede_other.check_program("genisoimage -help"):
 			errors+="genisoimage/mkisofs\n"
@@ -286,22 +302,31 @@ def program_exit(widget):
 	
 	gtk.main_quit()
 
+
+
 if errors!="":
-	w=arbol.get_widget("programs_label")
+	arbol.add_from_file(os.path.join(glade,"wprograms.ui"))
+	w=arbol.get_object("programs_label")
 	w.set_text(errors)
-	wprograms=arbol.get_widget("wprograms")
+	wprograms=arbol.get_object("wprograms")
 	wprograms.show()
-	w=arbol.get_widget("program_exit")
+	w=arbol.get_object("program_exit")
 	w.connect("clicked",program_exit)
 	wprograms.connect("destroy",program_exit)
 elif fonts_found==False:
-	wprograms=arbol.get_widget("wnofonts")
+	arbol.add_from_file(os.path.join(glade,"wnofonts.ui"))
+	wprograms=arbol.get_object("wnofonts")
 	wprograms.show()
-	w=arbol.get_widget("fonts_program_exit")
+	w=arbol.get_object("fonts_program_exit")
 	w.connect("clicked",program_exit)
 	wprograms.connect("destroy",program_exit)
 else:
 	new_file=devede_disctype.disctype(global_vars)
 
 gtk.main()
+print "Saving configuration"
 devede_other.save_config(global_vars)
+print "Exiting"
+print "Have a nice day"
+sys.stdout.flush()
+sys.stderr.flush()
