@@ -1,8 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
-
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -36,13 +35,12 @@ import shutil
 import glob
 import posixpath
 import gtk
-import gtk.glade
+import devede_other
 import gobject
 import cairo
-if sys.platform=='win32':
+if (sys.platform=="win32") or (sys.platform=="win64"):
 	import win32api
 
-
 import devede_other
 import devede_video_convert
 import devede_subtitles
@@ -59,8 +57,8 @@ class create_all:
 
 	def cancel_clicked(self,widget,temp=False):
 		
-		newtree=gtk.glade.XML(self.gladefile,"wcancel_job_dialog",domain="devede")
-		window=newtree.get_widget("wcancel_job_dialog")
+		newtree=devede_other.create_tree(self,"wcancel_job_dialog",self.gladefile,False)
+		window=newtree.get_object("wcancel_job_dialog")
 		window.show()
 		value=window.run()
 		window.hide()
@@ -73,8 +71,8 @@ class create_all:
 		gobject.source_remove(self.timer)
 		self.window.hide()
 		self.window.destroy()
-		newtree=gtk.glade.XML(self.gladefile,"waborted_dialog",domain="devede")
-		window=newtree.get_widget("waborted_dialog")
+		newtree=devede_other.create_tree(self,"waborted_dialog",self.gladefile,False)
+		window=newtree.get_object("waborted_dialog")
 		window.show()
 		window.run()
 		window.hide()
@@ -87,17 +85,17 @@ class create_all:
 
 	def iso_changed(self,args,arbol):
 
-		iso_name=arbol.get_widget("iso_filename")
-		iso_folder=arbol.get_widget("final_directory")
+		iso_name=arbol.get_object("iso_filename")
+		iso_folder=arbol.get_object("final_directory")
 	
-		w=arbol.get_widget("button_folder_accept")
+		w=arbol.get_object("button_folder_accept")
 	
 		mode=True
 	
 		if iso_name.get_text()=="":
 			mode=False
 		
-		folder=iso_folder.get_filename()
+		folder=iso_folder.get_current_folder()
 		if folder==None:
 			mode=False
 		elif folder=="":
@@ -113,12 +111,14 @@ class create_all:
 		# TODO Windows Stuff
 		estado=''
 		freespace=''
-		if sys.platform!='win32':
+		if (sys.platform!="win32") and (sys.platform!="win64"):
+			print "Checking "+str(filefolder)
 			estado=os.statvfs(filefolder) # eg. f="C:\Documents and Settings\User name\Desktop"
 			freespace=95*estado.f_bsize*estado.f_bavail/100000
 		else:
 			try:
-				spc, bps, fc, tc = win32api.GetDiskFreeSpace(filefolder)
+				test_drive = os.path.splitdrive(filefolder)[0] + "\\" # So it will also work on Windows 2000 
+				spc, bps, fc, tc = win32api.GetDiskFreeSpace(test_drive)
 				freespace=fc * spc * bps
 
 			except ImportError:
@@ -151,19 +151,18 @@ class create_all:
 		self.gladefile=gladefile
 		self.structure=structure
 		self.global_vars=global_vars
-		self.tree=gtk.glade.XML(self.gladefile,"wprogress",domain="devede")
-		self.tree.signal_autoconnect(self)
+		self.tree=devede_other.create_tree(self,"wprogress",self.gladefile)
 		
-		self.window=self.tree.get_widget("wprogress")
-		self.partial=self.tree.get_widget("progresspartial")
+		self.window=self.tree.get_object("wprogress")
+		self.partial=self.tree.get_object("progresspartial")
 		self.erase_temp=global_vars["erase_temporary_files"]
 		self.iso_creator=global_vars["iso_creator"]
 
 		self.queue=[]
 		self.current_action=0
 		self.actions=global_vars["number_actions"]
-		self.total=self.tree.get_widget("progress_total")
-		self.label=self.tree.get_widget("lcreating")
+		self.total=self.tree.get_object("progress_total")
+		self.label=self.tree.get_object("lcreating")
 		self.total.set_fraction(0)
 		self.partial.set_fraction(0)
 		self.partial.set_text("0%")
@@ -181,11 +180,23 @@ class create_all:
 		for element in self.structure:
 			chapter=0
 			for element2 in element[1:]:
-				self.queue.append(["C",title,chapter])
+				if self.structure[title][chapter+1]["twopass"] == True:
+					self.queue.append(["C1",title,chapter])
+					self.queue.append(["C2",title,chapter])
+				else:
+					self.queue.append(["C",title,chapter])
 				stream=0
 				for element3 in element2["sub_list"]:
 					self.queue.append(["S",title,chapter,stream])
 					stream+=1
+
+				#if self.structure[title][chapter+1]["twopass"] == True:
+				#	self.queue.append(["C2",title,chapter])
+				#	stream=0
+				#	for element3 in element2["sub_list"]:
+				#		self.queue.append(["S",title,chapter,stream])
+				#		stream+=1
+						
 				chapter+=1
 			title+=1
 
@@ -193,12 +204,12 @@ class create_all:
 	def preview(self,filefolder):
 		
 		self.init_queue()
-		newtree=gtk.glade.XML(self.gladefile,"wpreview_dialog",domain="devede")
-		timev=newtree.get_widget("seconds_preview")
+		newtree=devede_other.create_tree(self,"wpreview_dialog",self.gladefile,False)
+		timev=newtree.get_object("seconds_preview")
 		timev.set_value(60)
-		path=newtree.get_widget("temporary_files")
+		path=newtree.get_object("temporary_files")
 		path.set_filename(filefolder)
-		w=newtree.get_widget("wpreview_dialog")
+		w=newtree.get_object("wpreview_dialog")
 		w.show()
 		ret=w.run()
 		w.hide()
@@ -236,6 +247,11 @@ class create_all:
 		return self.filefolder
 		
 
+	def on_iso_filename_activate(self,widg,ventana):
+		
+		ventana.response(-6)
+
+
 	def create_disc(self):
 		
 		self.time=0
@@ -249,8 +265,8 @@ class create_all:
 				break
 			
 		if empty:
-			newtree=gtk.glade.XML(self.gladefile,"wempty_titles_dialog",domain="devede")
-			w=newtree.get_widget("wempty_titles_dialog")
+			newtree=devede_other.create_tree(self,"wempty_titles_dialog",self.gladefile,False)
+			w=newtree.get_object("wempty_titles_dialog")
 			w.show()
 			value=w.run()
 			w.hide()
@@ -260,23 +276,64 @@ class create_all:
 
 		# ask the folder and filename
 		
-		newtree=gtk.glade.XML(self.gladefile,"wfolder_dialog",domain="devede")
-		wdir=newtree.get_widget("final_directory")
-		wfile=newtree.get_widget("iso_filename")
+		newtree=devede_other.create_tree(self,"wfolder_dialog",self.gladefile,False)
+		wdir=newtree.get_object("final_directory")
+		if self.global_vars["finalfolder"]!="":
+			wdir.set_current_folder(self.global_vars["finalfolder"])
+		wfile=newtree.get_object("iso_filename")
+		wfolder_dialog=newtree.get_object("wfolder_dialog")
 		wfile.set_text("movie")
+		wfile.connect("activate",self.on_iso_filename_activate,wfolder_dialog)
 		wfile.connect("changed",self.iso_changed,newtree)
-		self.iso_changed("",newtree)
-		w=newtree.get_widget("wfolder_dialog")
-		w.show()
-		value=w.run()
+		wdir.connect("current-folder-changed",self.iso_changed,newtree)
+		#self.iso_changed("",newtree)
+
+		wfolder_dialog.show()
+		wfile.grab_focus()
+		value=wfolder_dialog.run()
+		
 		self.filename=wfile.get_text()
-		self.filefolder=wdir.get_filename()
-		if self.filefolder[-1]!=os.sep:
-			self.filefolder+=os.sep
-		w.hide()
-		w.destroy()
+		self.filename.replace("/","_")
+		self.filename.replace("|","_")
+		self.filename.replace("\\","_")
+			
+		filefolder=wdir.get_current_folder()
+		
+		wfolder_dialog.hide()
+		wfolder_dialog.destroy()
 		if value!=-6:
 			return False
+		
+		self.global_vars["finalfolder"]=filefolder
+		
+		filefolder2=os.path.join(filefolder,self.filename)
+		
+		self.filefolder=filefolder2
+		
+		if self.filefolder[-1]!=os.sep:
+			self.filefolder+=os.sep
+		
+		if (os.path.exists(filefolder2)):
+			newtree=devede_other.create_tree(self,"wfolder_exists",self.gladefile,False)
+			w=newtree.get_object("wfolder_exists")
+			wtext=newtree.get_object("folder_exists_label")
+			wtext.set_text(_("The file or folder\n\n%(folder)s\n\nalready exists. If you continue, it will be deleted.") % {'folder':filefolder2})
+			w.show()
+			value=w.run()
+			w.hide()
+			w.destroy()
+			if value!=2:
+				return False
+		
+		try:
+			os.remove(filefolder2)
+		except:
+			pass
+		
+		try:
+			os.mkdir(filefolder2)
+		except:
+			pass
 	
 		self.eraser=devede_delete.delete_files(self.filename,self.filefolder)
 		hasfree,msg=self.check_free_space(self.filefolder,self.structure,self.actions,self.erase_temp,self.global_vars["menu_sound_duration"])
@@ -298,11 +355,12 @@ class create_all:
 		counter=0
 		counter2=0
 		if (self.disk_type=="dvd"):
-			nelements=xml_files.get_elements_per_menu()
-			while (len(self.structure[counter:])!=0):
-				self.queue.append(["M1",xml_files,counter,counter2])
-				counter+=nelements
-				counter2+=1
+			if xml_files.do_menus():
+				nelements=xml_files.get_elements_per_menu()
+				while (len(self.structure[counter:])!=0):
+					self.queue.append(["M1",xml_files,counter,counter2])
+					counter+=nelements
+					counter2+=1
 
 		self.init_queue()
 
@@ -339,13 +397,16 @@ class create_all:
 		self.total.set_text(str(self.current_action)+"/"+str(len(self.queue)-1))
 		self.total.set_fraction(float(self.current_action)/(float(len(self.queue)-1)))
 		if self.runner!=None:
-			retval=self.runner.refresh()
+			if self.runner.initerror:
+				retval=-1;
+			else:
+				retval=self.runner.refresh()
 			if retval==0: # no error, still running
 				return True
 			else:
 				self.current_action+=1
 				retval=self.runner.wait_end()
-				if retval!=0:
+				if (retval!=0) or (self.runner.initerror):
 					self.window.hide()
 					self.window.destroy()
 					if self.runner.print_error==None:
@@ -364,10 +425,21 @@ class create_all:
 			self.runner.create_menu1(action[2],action[3],self.global_vars["multicore"])
 			return True
 		
-		if action[0]=="C":
+		if (action[0]=='C') or (action[0]=='C1') or (action[0]=='C2'):
 			title=action[1]
 			chapter=action[2]
-			self.runner=devede_video_convert.video_converter(self.structure[title][chapter+1],self.filename,self.filefolder,self.partial,self.label,self.global_vars["disctocreate"],title+1,chapter+1,self.global_vars["multicore"],self.seconds)
+			if action[0]=="C":
+				encpass = 0
+			else:
+				encpass = int(action[0][1])
+			print "Segundos "+str(self.seconds)
+			self.runner=devede_video_convert.video_converter(self.global_vars,self.structure[title][chapter+1],self.filename,self.filefolder,self.partial,self.label,self.global_vars["disctocreate"],title+1,chapter+1,self.global_vars["multicore"],self.seconds, encpass)
+			return True
+		
+		if action[0]=="C2":
+			title=action[1]
+			chapter=action[2]
+			self.runner=devede_video_convert.video_converter(self.structure[title][chapter+1],self.filename,self.filefolder,self.partial,self.label,self.global_vars["disctocreate"],title+1,chapter+1,self.global_vars["multicore"],self.seconds, 2)
 			return True
 		
 		if action[0]=="S":
@@ -380,7 +452,7 @@ class create_all:
 		if action[0]=="PREVIEW":
 			self.window.hide()
 			self.window.destroy()
-			if sys.platform=='win32':
+			if (sys.platform=="win32") or (sys.platform=="win64"):
 				mplay="mplayer.exe"
 			else:
 		 		mplay="mplayer"
@@ -389,9 +461,9 @@ class create_all:
 		 		fname+="avi"
 		 	else:
 		 		fname+="mpg"
-			parameters=[mplay,"-sid","0",fname]
-			newtree=gtk.glade.XML(self.gladefile,"wpreviewagain_dialog",domain="devede")
-			w=newtree.get_widget("wpreviewagain_dialog")
+			parameters=[mplay,"-sid","0",fname,"-loop","1"]
+			newtree=devede_other.create_tree(self,"wpreviewagain_dialog",self.gladefile,False)
+			w=newtree.get_object("wpreviewagain_dialog")
 			while True:
 				salida=devede_executor.executor("previewfile",self.filefolder,None)
 				salida.launch_program(parameters,output=False)
@@ -431,11 +503,11 @@ class create_all:
 
 		self.window.hide()
 		self.window.destroy()
-		newtree=gtk.glade.XML(self.gladefile,"wend_dialog",domain="devede")
-		label=newtree.get_widget("elapsed")
+		newtree=devede_other.create_tree(self,"wend_dialog",self.gladefile,False)
+		label=newtree.get_object("elapsed")
 		tiempo2=devede_other.return_time(time.time()-self.tiempo,True)
 		label.set_text(tiempo2)
-		window=newtree.get_widget("wend_dialog")
+		window=newtree.get_object("wend_dialog")
 		window.show()
 		window.run()
 		window.hide()
