@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -19,7 +19,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
+import gtk
 import cairo
 import time
 import sys
@@ -38,6 +38,12 @@ class xml_files(devede_executor.executor):
 		self.print_error=_("Failed to create the menues.")
 		self.output=False
 		self.structure=structure
+		self.with_menu=global_vars["with_menu"]
+		if (len(structure)==1) and (len(structure[0])==2) and (not self.with_menu):
+			self.onlyone=True
+		else:
+			self.onlyone=False
+		
 		self.do_menu=global_vars["do_menu"]
 		self.menu_bg=global_vars["menu_bg"]
 		self.menu_sound=global_vars["menu_sound"]
@@ -67,10 +73,13 @@ class xml_files(devede_executor.executor):
 		self.lines_per_menu=10
 		
 		counter=0
-		self.nmenues=0
-		while (len(self.structure[counter:])!=0):
-			counter+=self.elements_per_menu
-			self.nmenues+=1
+		if self.with_menu:
+			self.nmenues=0
+			while (len(self.structure[counter:])!=0):
+				counter+=self.elements_per_menu
+				self.nmenues+=1
+		else:
+			self.nmenues=1
 		
 		self.margin_x=0.1
 		self.shadow_offset=0.0025
@@ -78,6 +87,10 @@ class xml_files(devede_executor.executor):
 		self.print_error=None
 
 
+	def do_menus(self):
+		return self.with_menu
+
+
 	def wait_end(self):
 		
 		if self.print_error!=None:
@@ -108,6 +121,16 @@ class xml_files(devede_executor.executor):
 			return _("Failed to write to the destination directory.\nCheck that you have privileges and free space there.")
 	
 	
+	def expand_xml(self,text):
+		
+		text=text.replace('&','&amp;')
+		text=text.replace('<','&lt;')
+		text=text.replace('>','&gt;')
+		text=text.replace('"','&quot;')
+		text=text.replace("'",'&apos;')
+		return text
+	
+	
 	def create_xml(self):
 
 		""" Creates the XML file for DVDAuthor """
@@ -122,155 +145,172 @@ class xml_files(devede_executor.executor):
 
 		try:
 			fichero=open(self.filefolder+self.filename+".xml","w")
-			fichero.write('<dvdauthor dest="'+self.filefolder+self.filename+'">\n')
-			fichero.write('\t<vmgm>\n')
+			fichero.write('<dvdauthor dest="'+self.expand_xml(self.filefolder+self.filename)+'">\n')
 			
-			# MENU
-			
-			# in the FPC we do a jump to the first menu in the first titleset if we wanted MENU
-			# or we jump to the second titleset if we didn't want MENU at startup
-			
-			fichero.write('\t\t<fpc>\n')
-			fichero.write('\t\t\tg0=100;\n')
-			if self.do_menu:
-				fichero.write('\t\t\tg1=0;\n')
+			if self.onlyone:
+				fichero.write('\t<vmgm />\n')
 			else:
-				fichero.write('\t\t\tg1=100;\n')
-			fichero.write('\t\t\tg2=1024;\n')
-			fichero.write('\t\t\tjump menu 1;\n')
-			fichero.write('\t\t</fpc>\n')
 			
-			# in the VMGM menu we create a code to jump to the title specified in G0
-			# but if the title is 100, we jump to the menus. There we show the menu number
-			# contained in G1
-			
-			fichero.write("\t\t<menus>\n")
+				fichero.write('\t<vmgm>\n')
 				
-			fichero.write('\t\t\t<video format="')
-			if self.menu_PAL:
-				fichero.write("pal")
-			else:
-				fichero.write("ntsc")
-			fichero.write('" aspect="4:3"> </video>\n')
-
-			fichero.write('\t\t\t<pgc>\n')
-			fichero.write('\t\t\t\t<pre>\n')
-			
-			counter=1
-			for element in self.structure:
-				for element2 in element[1:]:
-					fichero.write('\t\t\t\t\tif (g0 eq '+str(counter)+') {\n')
-					fichero.write('\t\t\t\t\t\tjump titleset '+str(1+counter)+' menu;\n')
-					fichero.write('\t\t\t\t\t}\n')
-					counter+=1
-			fichero.write('\t\t\t\t\tif (g0 eq 100) {\n')
-			fichero.write('\t\t\t\t\t\tg2=1024;\n')
-			fichero.write('\t\t\t\t\t\tjump titleset 1 menu;\n')
-			fichero.write('\t\t\t\t\t}\n')
-			fichero.write('\t\t\t\t</pre>\n')
-			# fake video (one black picture with one second of sound) to ensure 100% compatibility
-			fichero.write('\t\t\t\t<vob file="')
-			if self.menu_PAL:
-				fichero.write(str(os.path.join(self.installpath,"base_pal.mpg")))
-			else:
-				fichero.write(str(os.path.join(self.installpath,"base_ntsc.mpg")))
-			fichero.write('"></vob>\n')
-			fichero.write('\t\t\t</pgc>\n')
-			fichero.write('\t\t</menus>\n')
-			fichero.write("\t</vmgm>\n")
-			
-			fichero.write("\n")
-			
-			# the first titleset contains all the menus. G1 allows us to jump to the desired menu
-			
-			fichero.write('\t<titleset>\n')
-			fichero.write('\t\t<menus>\n')
-			fichero.write('\t\t\t<video format="')
-			if self.menu_PAL:
-				fichero.write("pal")
-			else:
-				fichero.write("ntsc")
-			fichero.write('" aspect="4:3"> </video>\n')
-			
-			button_counter=0
-			for menu_number in range(self.nmenues):
+				# MENU
+				
+				# in the FPC we do a jump to the first menu in the first titleset if we wanted MENU
+				# or we jump to the second titleset if we didn't want MENU at startup
+				
+				fichero.write('\t\t<fpc>\n')
+				fichero.write('\t\t\tg0=100;\n')
+				if self.do_menu and self.with_menu:
+					fichero.write('\t\t\tg1=0;\n')
+				else:
+					fichero.write('\t\t\tg1=100;\n')
+				fichero.write('\t\t\tg2=1024;\n')
+				fichero.write('\t\t\tjump menu 1;\n')
+				fichero.write('\t\t</fpc>\n')
+				
+				# in the VMGM menu we create a code to jump to the title specified in G0
+				# but if the title is 100, we jump to the menus. There we show the menu number
+				# contained in G1
+				
+				fichero.write("\t\t<menus>\n")
+					
+				fichero.write('\t\t\t<video format="')
+				if self.menu_PAL:
+					fichero.write("pal")
+				else:
+					fichero.write("ntsc")
+				fichero.write('" aspect="4:3"> </video>\n')
+	
 				fichero.write('\t\t\t<pgc>\n')
 				fichero.write('\t\t\t\t<pre>\n')
-				# first we recover the currently selected button
-				fichero.write('\t\t\t\t\ts8=g2;\n')
-				if menu_number==0: # here we add some code to jump to each menu
-					for menu2 in range(self.nmenues-1):
-						fichero.write('\t\t\t\t\tif (g1 eq '+str(menu2+1)+') {\n')
-						fichero.write('\t\t\t\t\t\tjump menu '+str(menu2+2)+';\n')
-						fichero.write('\t\t\t\t\t}\n')
-					
-					# this code is to fix a bug in some players
-					fichero.write('\t\t\t\t\tif (g1 eq 100) {\n')
-					fichero.write('\t\t\t\t\t\tjump title 1;\n')#menu '+str(self.nmenues+1)+';\n')
-					fichero.write('\t\t\t\t\t}\n')
-					
-				fichero.write('\t\t\t\t</pre>\n')
-				fichero.write('\t\t\t\t<vob file="'+str(os.path.join(self.filefolder,self.filename))+'_menu2_'+str(menu_number)+'.mpg"></vob>\n')
-				cantidad=len(self.structure[self.elements_per_menu*menu_number:(menu_number+1)*self.elements_per_menu])
-				for nbutton in range(cantidad):
-					fichero.write('\t\t\t\t<button name="boton')
-					fichero.write(str(menu_number))
-					fichero.write('x')
-					fichero.write(str(nbutton))
-					fichero.write('"> g0='+str(title_list[button_counter])+'; jump vmgm menu; </button>\n')
-					button_counter+=1
-					
-				if (menu_number!=0):
-					fichero.write('\t\t\t\t<button name="boton')
-					fichero.write(str(menu_number))
-					fichero.write('p"> g1=')
-					fichero.write(str(menu_number-1))
-					fichero.write('; g2=1024; jump menu ')
-					fichero.write(str(menu_number))
-					fichero.write('; </button>\n')
-					
-				if (menu_number!=self.nmenues-1) and (self.nmenues>1):
-					fichero.write('\t\t\t\t<button name="boton')
-					fichero.write(str(menu_number))
-					fichero.write('n"> g1=')
-					fichero.write(str(menu_number+1))
-					fichero.write('; g2=1024; jump menu ')
-					fichero.write(str(menu_number+2))
-					fichero.write('; </button>\n')
 				
+				counter=1
+				for element in self.structure:
+					for element2 in element[1:]:
+						fichero.write('\t\t\t\t\tif (g0 eq '+str(counter)+') {\n')
+						fichero.write('\t\t\t\t\t\tjump titleset '+str(1+counter)+' menu;\n')
+						fichero.write('\t\t\t\t\t}\n')
+						counter+=1
+				fichero.write('\t\t\t\t\tif (g0 eq 100) {\n')
+				fichero.write('\t\t\t\t\t\tg2=1024;\n')
+				fichero.write('\t\t\t\t\t\tjump titleset 1 menu;\n')
+				fichero.write('\t\t\t\t\t}\n')
+				fichero.write('\t\t\t\t</pre>\n')
+				# fake video (one black picture with one second of sound) to ensure 100% compatibility
+				fichero.write('\t\t\t\t<vob file="')
+				if self.menu_PAL:
+					fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_pal.mpg"))))
+				else:
+					fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_ntsc.mpg"))))
+				fichero.write('"></vob>\n')
+				fichero.write('\t\t\t</pgc>\n')
+				fichero.write('\t\t</menus>\n')
+				fichero.write("\t</vmgm>\n")
+				
+				fichero.write("\n")
+				
+				# the first titleset contains all the menus. G1 allows us to jump to the desired menu
+				
+				fichero.write('\t<titleset>\n')
+				fichero.write('\t\t<menus>\n')
+				fichero.write('\t\t\t<video format="')
+				if self.menu_PAL:
+					fichero.write("pal")
+				else:
+					fichero.write("ntsc")
+				fichero.write('" aspect="4:3"> </video>\n')
+				
+				button_counter=0
+				for menu_number in range(self.nmenues):
+					fichero.write('\t\t\t<pgc>\n')
+					fichero.write('\t\t\t\t<pre>\n')
+					# first we recover the currently selected button
+					fichero.write('\t\t\t\t\ts8=g2;\n')
+					if menu_number==0: # here we add some code to jump to each menu
+						for menu2 in range(self.nmenues-1):
+							fichero.write('\t\t\t\t\tif (g1 eq '+str(menu2+1)+') {\n')
+							fichero.write('\t\t\t\t\t\tjump menu '+str(menu2+2)+';\n')
+							fichero.write('\t\t\t\t\t}\n')
+						
+						# this code is to fix a bug in some players
+						fichero.write('\t\t\t\t\tif (g1 eq 100) {\n')
+						fichero.write('\t\t\t\t\t\tjump title 1;\n')#menu '+str(self.nmenues+1)+';\n')
+						fichero.write('\t\t\t\t\t}\n')
+						
+					fichero.write('\t\t\t\t</pre>\n')
+					fichero.write('\t\t\t\t<vob file="')
+					if self.with_menu:
+						fichero.write(self.expand_xml(str(os.path.join(self.filefolder,self.filename)))+'_menu2_'+str(menu_number)+'.mpg"')
+					else:
+						if self.menu_PAL:
+							fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_pal.mpg")))+'"')
+						else:
+							fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_ntsc.mpg")))+'"')
+					fichero.write('></vob>\n')
+					
+					if self.with_menu:
+						cantidad=len(self.structure[self.elements_per_menu*menu_number:(menu_number+1)*self.elements_per_menu])
+						for nbutton in range(cantidad):
+							fichero.write('\t\t\t\t<button name="boton')
+							fichero.write(str(menu_number))
+							fichero.write('x')
+							fichero.write(str(nbutton))
+							fichero.write('"> g0='+str(title_list[button_counter])+'; jump vmgm menu; </button>\n')
+							button_counter+=1
+							
+						if (menu_number!=0):
+							fichero.write('\t\t\t\t<button name="boton')
+							fichero.write(str(menu_number))
+							fichero.write('p"> g1=')
+							fichero.write(str(menu_number-1))
+							fichero.write('; g2=1024; jump menu ')
+							fichero.write(str(menu_number))
+							fichero.write('; </button>\n')
+							
+						if (menu_number!=self.nmenues-1) and (self.nmenues>1):
+							fichero.write('\t\t\t\t<button name="boton')
+							fichero.write(str(menu_number))
+							fichero.write('n"> g1=')
+							fichero.write(str(menu_number+1))
+							fichero.write('; g2=1024; jump menu ')
+							fichero.write(str(menu_number+2))
+							fichero.write('; </button>\n')
+					
+					fichero.write('\t\t\t\t<post>\n')
+					fichero.write('\t\t\t\t\tg2=s8;\n')
+					fichero.write('\t\t\t\t\tg1='+str(menu_number)+';\n')
+					fichero.write('\t\t\t\t\tjump menu '+str(menu_number+1)+';\n')
+					fichero.write('\t\t\t\t</post>\n')
+					fichero.write('\t\t\t</pgc>\n')
+				
+				fichero.write('\t\t</menus>\n')
+				fichero.write('\t\t<titles>\n')
+				fichero.write('\t\t\t<video format="')
+				if self.menu_PAL:
+					fichero.write("pal")
+				else:
+					fichero.write("ntsc")
+				fichero.write('" aspect="4:3"> </video>\n')
+				fichero.write('\t\t\t<pgc>\n')
+				fichero.write('\t\t\t\t<vob file="')
+				if self.menu_PAL:
+					fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_pal.mpg"))))
+				else:
+					fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_ntsc.mpg"))))
+				fichero.write('"></vob>\n')
 				fichero.write('\t\t\t\t<post>\n')
-				fichero.write('\t\t\t\t\tg2=s8;\n')
-				fichero.write('\t\t\t\t\tg1='+str(menu_number)+';\n')
-				fichero.write('\t\t\t\t\tjump menu '+str(menu_number+1)+';\n')
+				fichero.write('\t\t\t\t\tg0=1;\n')
+				fichero.write('\t\t\t\t\tg1=0;\n')
+				fichero.write('\t\t\t\t\tg2=1024;\n')
+				fichero.write('\t\t\t\t\tcall vmgm menu entry title;\n')
 				fichero.write('\t\t\t\t</post>\n')
 				fichero.write('\t\t\t</pgc>\n')
-			
-			fichero.write('\t\t</menus>\n')
-			fichero.write('\t\t<titles>\n')
-			fichero.write('\t\t\t<video format="')
-			if self.menu_PAL:
-				fichero.write("pal")
-			else:
-				fichero.write("ntsc")
-			fichero.write('" aspect="4:3"> </video>\n')
-			fichero.write('\t\t\t<pgc>\n')
-			fichero.write('\t\t\t\t<vob file="')
-			if self.menu_PAL:
-				fichero.write(str(os.path.join(self.installpath,"base_pal.mpg")))
-			else:
-				fichero.write(str(os.path.join(self.installpath,"base_ntsc.mpg")))
-			fichero.write('"></vob>\n')
-			fichero.write('\t\t\t\t<post>\n')
-			fichero.write('\t\t\t\t\tg0=1;\n')
-			fichero.write('\t\t\t\t\tg1=0;\n')
-			fichero.write('\t\t\t\t\tg2=1024;\n')
-			fichero.write('\t\t\t\t\tcall vmgm menu entry title;\n')
-			fichero.write('\t\t\t\t</post>\n')
-			fichero.write('\t\t\t</pgc>\n')
-			fichero.write('\t\t</titles>\n')
-			fichero.write("\t</titleset>\n")
-
-			fichero.write("\n")
+				fichero.write('\t\t</titles>\n')
+				fichero.write("\t</titleset>\n")
+	
+				fichero.write("\n")
+				
+			# Now we create the titleset for each video
 			
 			total_t=len(self.structure)
 			titleset=1
@@ -314,35 +354,34 @@ class xml_files(devede_executor.executor):
 							fwide=False
 					
 					fichero.write("\t<titleset>\n")
-					fichero.write("\t\t<menus>\n")
-					fichero.write('\t\t\t<video format="'+pal_ntsc+'" aspect="'+faspect+'"')
-					if fwide:
-						fichero.write(' widescreen="nopanscan"')
-					fichero.write('> </video>\n')
-					
-					fichero.write("\t\t\t<pgc>\n")
-					fichero.write("\t\t\t\t<pre>\n")
-					fichero.write('\t\t\t\t\tif (g0 eq 100) {\n')
-					fichero.write('\t\t\t\t\t\tjump vmgm menu entry title;\n')
-					fichero.write('\t\t\t\t\t}\n')
-					fichero.write('\t\t\t\t\tg0=100;\n')
-					fichero.write('\t\t\t\t\tg1='+str(titles/self.elements_per_menu)+';\n')
-					fichero.write('\t\t\t\t\tjump title 1;\n')
-					fichero.write('\t\t\t\t</pre>\n')
-					# fake video to ensure compatibility
-					fichero.write('\t\t\t\t<vob file="')
-					if ispal:
-						fichero.write(str(os.path.join(self.installpath,"base_pal")))
-					else:
-						fichero.write(str(os.path.join(self.installpath,"base_ntsc")))
-					if fwide:
-						fichero.write("_wide")
-					fichero.write('.mpg"></vob>\n')
-					fichero.write("\t\t\t</pgc>\n")
-					fichero.write("\t\t</menus>\n")
-					
-					
-					
+					if not self.onlyone:
+						fichero.write("\t\t<menus>\n")
+						fichero.write('\t\t\t<video format="'+pal_ntsc+'" aspect="'+faspect+'"')
+						if fwide:
+							fichero.write(' widescreen="nopanscan"')
+						fichero.write('> </video>\n')
+						
+						fichero.write("\t\t\t<pgc>\n")
+						fichero.write("\t\t\t\t<pre>\n")
+						fichero.write('\t\t\t\t\tif (g0 eq 100) {\n')
+						fichero.write('\t\t\t\t\t\tjump vmgm menu entry title;\n')
+						fichero.write('\t\t\t\t\t}\n')
+						fichero.write('\t\t\t\t\tg0=100;\n')
+						fichero.write('\t\t\t\t\tg1='+str(titles/self.elements_per_menu)+';\n')
+						fichero.write('\t\t\t\t\tjump title 1;\n')
+						fichero.write('\t\t\t\t</pre>\n')
+						# fake video to ensure compatibility
+						fichero.write('\t\t\t\t<vob file="')
+						if ispal:
+							fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_pal"))))
+						else:
+							fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_ntsc"))))
+						if fwide:
+							fichero.write("_wide")
+						fichero.write('.mpg"></vob>\n')
+						fichero.write("\t\t\t</pgc>\n")
+						fichero.write("\t\t</menus>\n")
+
 					fichero.write("\t\t<titles>\n")
 					fichero.write('\t\t\t<video format="'+pal_ntsc+'" aspect="'+faspect+'"')
 					if fwide:
@@ -350,10 +389,15 @@ class xml_files(devede_executor.executor):
 					fichero.write('> </video>\n')
 					
 					for element3 in element2["sub_list"]:
-						fichero.write('\t\t\t<subpicture lang="'+str(element3["sub_language"][:2].lower())+'" />\n')
-					fichero.write("\t\t\t<pgc>\n")
+						fichero.write('\t\t\t<subpicture lang="'+self.expand_xml(str(element3["sub_language"][:2].lower()))+'" />\n')
+					fichero.write('\t\t\t<pgc>\n')
+					if (element2["force_subs"]) and (len(element2["sub_list"])!=0):
+						fichero.write('\t\t\t\t<pre>\n')
+						fichero.write('\t\t\t\t\tsubtitle=64;\n')
+						fichero.write('\t\t\t\t</pre>\n')
+
 					currentfile=self.create_filename(self.filefolder+self.filename,titles+1,files+1,False)
-					fichero.write('\t\t\t\t<vob file="'+currentfile+'" ')
+					fichero.write('\t\t\t\t<vob file="'+self.expand_xml(currentfile)+'" ')
 					fichero.write('chapters="0')
 					if (element2["olength"]>5):
 						if (element2["lchapters"]!=0): # add chapters
@@ -365,39 +409,41 @@ class xml_files(devede_executor.executor):
 								seconds+=(toadd*60)
 						fichero.write(','+devede_other.return_time((element2["olength"]-2),False))
 					fichero.write('" />\n')
-					fichero.write('\t\t\t\t<post>\n')
-					files+=1
-					fichero.write('\t\t\t\t\tg1='+str(titles/self.elements_per_menu)+';\n')
-					if (files==num_chapters) and (action=="menu"): # last chapter
-						fichero.write('\t\t\t\t\tg0=100;\n')
-						fichero.write('\t\t\t\t\tcall vmgm menu entry title;\n')
-					else:
-						fichero.write('\t\t\t\t\tg0=')
-						if (files==num_chapters): # last chapter; do ACTION
-							if action=="prev":
-								if titles==0:
-									prev_t=total_t-1
-								else:
-									prev_t=titles-1
-								fichero.write(str(title_list[prev_t]))
-							elif action=="loop":
-								fichero.write(str(title_list[titles]))
-							elif action=="next":
-								if titles==total_t-1:
-									next_t=0
-								else:
-									next_t=titles+1
-								fichero.write(str(title_list[next_t]))
-							elif action=="last":
-								fichero.write(str(title_list[total_t-1]))
-							else:
-								fichero.write('1') # first
+					
+					if not self.onlyone:
+						fichero.write('\t\t\t\t<post>\n')
+						files+=1
+						fichero.write('\t\t\t\t\tg1='+str(titles/self.elements_per_menu)+';\n')
+						if (files==num_chapters) and (action=="menu"): # last chapter
+							fichero.write('\t\t\t\t\tg0=100;\n')
+							fichero.write('\t\t\t\t\tcall vmgm menu entry title;\n')
 						else:
-							 # jump to next chapter in title
-							fichero.write(str(title_list[titles]+files))
-						fichero.write(';\n')
-						fichero.write('\t\t\t\t\tcall vmgm menu entry title;\n')
-					fichero.write('\t\t\t\t</post>\n')
+							fichero.write('\t\t\t\t\tg0=')
+							if (files==num_chapters): # last chapter; do ACTION
+								if action=="prev":
+									if titles==0:
+										prev_t=total_t-1
+									else:
+										prev_t=titles-1
+									fichero.write(str(title_list[prev_t]))
+								elif action=="loop":
+									fichero.write(str(title_list[titles]))
+								elif action=="next":
+									if titles==total_t-1:
+										next_t=0
+									else:
+										next_t=titles+1
+									fichero.write(str(title_list[next_t]))
+								elif action=="last":
+									fichero.write(str(title_list[total_t-1]))
+								else:
+									fichero.write('1') # first
+							else:
+								 # jump to next chapter in title
+								fichero.write(str(title_list[titles]+files))
+							fichero.write(';\n')
+							fichero.write('\t\t\t\t\tcall vmgm menu entry title;\n')
+						fichero.write('\t\t\t\t</post>\n')
 					fichero.write("\t\t\t</pgc>\n")
 					fichero.write("\t\t</titles>\n")
 					fichero.write("\t</titleset>\n")
@@ -412,6 +458,8 @@ class xml_files(devede_executor.executor):
 	
 	def create_menu1(self,counter,nelement,threads):
 	
+		""" Creates all the menu elements """
+	
 		self.threads=threads
 		self.counter=counter
 		self.nelement=nelement
@@ -473,9 +521,9 @@ class xml_files(devede_executor.executor):
 		try:
 			fichero=open(self.filefolder+self.filename+"_menu_"+str(nelement)+".xml","w")
 			fichero.write('<subpictures>\n<stream>\n<spu force="yes" start="00:00:00.00"')# transparent="000000"')
-			fichero.write(' image="'+self.filefolder+self.filename+'_menu'+str(nelement)+'_bg_inactive_out.png"')
-			fichero.write(' highlight="'+self.filefolder+self.filename+'_menu'+str(nelement)+'_bg_active_out.png"')
-			fichero.write(' select="'+self.filefolder+self.filename+'_menu'+str(nelement)+'_bg_select_out.png" >\n')
+			fichero.write(' image="'+self.expand_xml(self.filefolder+self.filename)+'_menu'+str(nelement)+'_bg_inactive_out.png"')
+			fichero.write(' highlight="'+self.expand_xml(self.filefolder+self.filename)+'_menu'+str(nelement)+'_bg_active_out.png"')
+			fichero.write(' select="'+self.expand_xml(self.filefolder+self.filename)+'_menu'+str(nelement)+'_bg_select_out.png" >\n')
 			if self.menu_PAL:
 				coord_y=[(92,128),(130,166),(168,204),(206,242),(244,280),(282,320),(322,358),(360,396),(398,436),(438,474),(476,512)]
 			else:
@@ -671,7 +719,19 @@ class xml_files(devede_executor.executor):
 
 		if paint_bg==0:
 			try:
-				sf_base=cairo.ImageSurface.create_from_png(self.menu_bg)
+				print "Uso "+str(self.menu_bg)
+				extra_pixbuf = gtk.gdk.pixbuf_new_from_file(self.menu_bg)
+				extra_x = extra_pixbuf.get_width()
+				extra_y = extra_pixbuf.get_height()
+
+				sf_base = cairo.ImageSurface(0,extra_x,extra_y)
+
+				extra_ct = cairo.Context(sf_base)
+				extra_ct2 = gtk.gdk.CairoContext(extra_ct)
+
+				extra_ct2.set_source_pixbuf(extra_pixbuf,0,0)
+				extra_ct2.paint()
+				extra_ct2.stroke()
 			except:
 				return None
 
@@ -680,25 +740,17 @@ class xml_files(devede_executor.executor):
 		else:
 			y=480.0
 
+		sf=cairo.ImageSurface(cairo.FORMAT_ARGB32,720,int(y))
+		cr=cairo.Context(sf)
 		if paint_bg!=0: # if we are creating something different than the base, we use a 1bit surface
-			sf=cairo.ImageSurface(cairo.FORMAT_A1,720,int(y))
-			sf2=cairo.ImageSurface(cairo.FORMAT_ARGB32,720,int(y))
-			cr=cairo.Context(sf)
+			fo=cairo.FontOptions()
+			fo.set_antialias(cairo.ANTIALIAS_NONE)
+			cr.set_font_options(fo)
+			cr.set_antialias(cairo.ANTIALIAS_NONE)
 		else:
-			sf=cairo.ImageSurface(cairo.FORMAT_ARGB32,720,int(y))
-			cr=cairo.Context(sf)
 			cr.set_source_rgb(1.0,1.0,1.0)
 			cr.paint()
 
-		#if paint_bg!=0:
-			# turn off font antialias (reduces color use in the image, same thing as using convert.exe)
-		#	fo = cairo.FontOptions()
-		#	fo.set_antialias(cairo.ANTIALIAS_NONE)
-			
-		#	cr.set_font_options(fo)
-			# turn off antialias
-		#	cr.set_antialias(cairo.ANTIALIAS_NONE)
-		
 		cr.identity_matrix()
 		
 		if paint_bg==0:
@@ -729,20 +781,20 @@ class xml_files(devede_executor.executor):
 				arrowshadowcolor=shadowcolor
 			elif paint_bg==1:
 				bgcolor=[0,0,0,0]
-				fontcolor=[0,0,0,65535]
-				arrowcolor=[0,0,0,65535]
+				fontcolor=self.activecolor
+				arrowcolor=self.activecolor
 				strokecolor=self.activecolor
 				arrowshadowcolor=None
 			elif paint_bg==2:
 				bgcolor=[0,0,0,0]
-				fontcolor=[0,0,0,65535]
-				arrowcolor=[0,0,0,65535]
+				fontcolor=self.activecolor
+				arrowcolor=self.activecolor
 				strokecolor=self.activecolor
 				arrowshadowcolor=None
 			else:
 				bgcolor=[0,0,0,0]
-				fontcolor=[0,0,0,65535]
-				arrowcolor=[0,0,0,65535]
+				fontcolor=self.inactivecolor
+				arrowcolor=self.inactivecolor
 				strokecolor=self.inactivecolor
 				arrowshadowcolor=None
 				
@@ -768,18 +820,6 @@ class xml_files(devede_executor.executor):
 			# check if we have to paint the PREVIOUS MENU button
 			if (element!=0) or ((self.extcr!=None) and (self.nmenues>1)):
 				self.menu_set_bg(cr, 0, pos_y, 0.4, bgcolor,arrowcolor,arrowshadowcolor)
-				
-			if paint_bg!=0:
-				cr2=cairo.Context(sf2)
-				cor=float(strokecolor[0])/65535.0
-				cog=float(strokecolor[1])/65535.0
-				cob=float(strokecolor[2])/65535.0
-				cr2.set_source_rgb(cor, cog, cob)
-				cr2.mask_surface(sf)
-				cr2.fill()
-
-		if paint_bg!=0:
-			sf=sf2
 
 		if self.extcr==None:
 			if paint_bg==0:
@@ -799,7 +839,7 @@ class xml_files(devede_executor.executor):
 		
 		self.mplexed=False
 		command_var=[]
-		if sys.platform=='win32':
+		if (sys.platform=="win32") or (sys.platform=="win64"):
 			command_var=["mencoder.exe"]
 		else:
 			command_var=["mencoder"]
@@ -853,7 +893,7 @@ class xml_files(devede_executor.executor):
 		command_var.append("-mf")
 		command_var.append("type=png:fps=1/"+str(self.menu_sound_duration))
 		origDir=os.getcwd()
-		if sys.platform=="win32":
+		if (sys.platform=="win32") or (sys.platform=="win64"):
 			temp=os.path.split(self.filefolder+self.filename+"_menu"+str(counter)+"_bg.png")
 			picDir=temp[0]
 			picName=temp[1]
@@ -865,14 +905,14 @@ class xml_files(devede_executor.executor):
 
 		self.launch_program(command_var)
 		
-		if sys.platform=="win32":
+		if (sys.platform=="win32") or (sys.platform=="win64"):
 			os.chdir(origDir)
 
 	
 	def menu_mplex_buttons(self,counter):
 	
 		self.mplexed=True
-		if sys.platform=='win32':
+		if (sys.platform=="win32") or (sys.platform=="win64"):
 			comando=["spumux.exe"]
 			# The -i -o is with a custom patched version of
 			# dvdauthor.  Best and easiest way of making it work
