@@ -20,6 +20,7 @@ install_locales()	# arg1=datadir.
 {
 	install_lang "${1}"	ca	ca		# Catala
 	install_lang "${1}"	cs	cs_CZ		# Czech
+	install_lang "${1}"	da	da		# Danish
 	install_lang "${1}"	de_DE	de_DE		# German
 	install_lang "${1}"	el	el		# Greek
 	install_lang "${1}"	es	es		# Spanish
@@ -35,6 +36,7 @@ install_locales()	# arg1=datadir.
 	install_lang "${1}"     sk      sk              # Slovak
 	install_lang "${1}"	sv	sv		#
 	install_lang "${1}"	zh_TW	zh_TW		# Taiwanese
+	install_lang "${1}"     zh_CN   zh_CN           # Simplified Chinese
 }
 
 
@@ -44,25 +46,36 @@ install_others()	# arg1=bindir, arg2=datadir, arg3=pkglibdir,
 {
 	install -m 755 -d "${DESTDIR}${1}"
 	install -m 755 "${scriptdir}/devede.py" "${DESTDIR}${1}/devede"
+	install -m 755 "${scriptdir}/devede_debug" "${DESTDIR}${1}/devede_debug"
+	install -m 755 "${scriptdir}/devede-debug" "${DESTDIR}${1}/devede-debug"
 
 	install -m 755 -d "${DESTDIR}${3}"
 	install "${scriptdir}"/devede_*.py "${DESTDIR}${3}/"
 
 	install -m 755 -d "${DESTDIR}${4}"
-	install -m 644 "${scriptdir}/devede.glade" "${DESTDIR}${4}/"
+	install -m 755 -d "${DESTDIR}${4}/backgrounds"
+	install -m 644 "${scriptdir}/interface"/* "${DESTDIR}${4}/"
 	install -m 644 "${scriptdir}/devedesans.ttf" "${DESTDIR}${4}/"
 	install -m 644 "${scriptdir}/pixmaps"/* "${DESTDIR}${4}/"
+        install -m 644 "${scriptdir}/pixmaps/backgrounds"/* "${DESTDIR}${4}/backgrounds/"
 	install -m 644 "${scriptdir}/devede.svg" "${DESTDIR}${4}/"
 
 	install -m 755 -d "${DESTDIR}${2}/pixmaps"
 	install -m 644 "${scriptdir}/devede.svg" "${DESTDIR}${2}/pixmaps/"
 
+        install -m 755 -d "${DESTDIR}${2}/pixmaps/backgrounds"
+        install -m 644 "${scriptdir}/devede.svg" "${DESTDIR}${2}/pixmaps/"
+
 	install -m 755 -d "${DESTDIR}${2}/applications"
 	install -m 644 "${scriptdir}/devede.desktop"			\
 						"${DESTDIR}${2}/applications/"
 
+	install -m 755 -d "${DESTDIR}${5}"
+	install -m 644 "${scriptdir}/docs"/c* "${DESTDIR}${5}"
+
 	install -m 755 -d "${DESTDIR}${5}/html"
-	install -m 644 "${scriptdir}/docs"/* "${DESTDIR}${5}/html"
+	install -m 644 "${scriptdir}/docs/html"/* "${DESTDIR}${5}/html"
+
 }
 
 
